==> jc-1.4.0.tar.gz: javax/print/attribute/HashDocAttributeSet.h <==
// public class javax.print.attribute.HashDocAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 1662af9d5fb8b24a javax_print_attribute_HashDocAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashDocAttributeSet_H_
#define _JC_javax_print_attribute_HashDocAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_DocAttribute$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$sub_refs	_jc_javax_print_attribute_HashDocAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$refs	_jc_javax_print_attribute_HashDocAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$nonrefs	_jc_javax_print_attribute_HashDocAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$object	_jc_javax_print_attribute_HashDocAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashDocAttributeSet$fields_struct	_jc_javax_print_attribute_HashDocAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashDocAttributeSet$vmethods	_jc_javax_print_attribute_HashDocAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashDocAttributeSet$vtable	_jc_javax_print_attribute_HashDocAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashDocAttributeSet$vtype	_jc_javax_print_attribute_HashDocAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashDocAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24DocAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashDocAttributeSet$fields_struct _jc_javax_print_attribute_HashDocAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *);
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$41e6cd57e20c3534(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$bdf5415a099a64cc(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$f0ee0739846bd461(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *, struct _jc_object_array *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashDocAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_HashDocAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashDocAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashDocAttributeSet$vmethods	javax_print_attribute_HashDocAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashDocAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashDocAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashDocAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashDocAttributeSet$refs {
    _jc_javax_print_attribute_HashDocAttributeSet$sub_refs	javax_print_attribute_HashDocAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashDocAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs	javax_print_attribute_HashDocAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashDocAttributeSet$object {
	_jc_javax_print_attribute_HashDocAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashDocAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashDocAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashDocAttributeSet$vtype _jc_javax_print_attribute_HashDocAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashDocAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashDocAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashDocAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/HashDocAttributeSet.h <==
// public class javax.print.attribute.HashDocAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 1662af9d5fb8b24a javax_print_attribute_HashDocAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashDocAttributeSet_H_
#define _JC_javax_print_attribute_HashDocAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_DocAttribute$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$sub_refs	_jc_javax_print_attribute_HashDocAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$refs	_jc_javax_print_attribute_HashDocAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$nonrefs	_jc_javax_print_attribute_HashDocAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashDocAttributeSet$object	_jc_javax_print_attribute_HashDocAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashDocAttributeSet$fields_struct	_jc_javax_print_attribute_HashDocAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashDocAttributeSet$vmethods	_jc_javax_print_attribute_HashDocAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashDocAttributeSet$vtable	_jc_javax_print_attribute_HashDocAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashDocAttributeSet$vtype	_jc_javax_print_attribute_HashDocAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashDocAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24DocAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashDocAttributeSet$fields_struct _jc_javax_print_attribute_HashDocAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$41e6cd57e20c3534(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$bdf5415a099a64cc(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashDocAttributeSet$method$_init$f0ee0739846bd461(_jc_env *, struct _jc_javax_print_attribute_HashDocAttributeSet$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashDocAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_HashDocAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashDocAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashDocAttributeSet$vmethods	javax_print_attribute_HashDocAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashDocAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashDocAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashDocAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashDocAttributeSet$refs {
    _jc_javax_print_attribute_HashDocAttributeSet$sub_refs	javax_print_attribute_HashDocAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashDocAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashDocAttributeSet$sub_nonrefs	javax_print_attribute_HashDocAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashDocAttributeSet$object {
	_jc_javax_print_attribute_HashDocAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashDocAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashDocAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashDocAttributeSet$vtype _jc_javax_print_attribute_HashDocAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashDocAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashDocAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashDocAttributeSet_H_ */
